colour.temperature Package — Colour 0.3.0 documentation

# colour.temperature Package

## Sub-Modules

- colour.temperature.cct Module
  - Correlated Colour Temperature \(T_{cp}\)

## Module Contents

`colour.temperature.` `CCT_to_uv`(CCT, Duv=0, method=u'Ohno 2013', **kwargs)

  Returns the CIE UCS colourspace uv chromaticity coordinates from given correlated colour temperature \(T_{cp}\) and \(\Delta_{uv}\) using given method.

  Parameters: | CCT (numeric) – Correlated colour temperature \(T_{cp}\). Duv (numeric) – \(\Delta_{uv}\). method (unicode) – (‘Ohno 2013’, ‘Robertson 1968’) Computation method. **kwargs (**) – Keywords arguments.
  Returns: | CIE UCS colourspace uv chromaticity coordinates.
  Return type: | tuple
  Raises: | `ValueError` – If the computation method is not defined.

  Examples

      >>> from colour import STANDARD_OBSERVERS_CMFS
      >>> cmfs = 'CIE 1931 2 Degree Standard Observer'
      >>> cmfs = STANDARD_OBSERVERS_CMFS.get(cmfs)
      >>> CCT = 6507.4342201047066
      >>> Duv = 0.003223690901512735
      >>> CCT_to_uv(CCT, Duv, cmfs=cmfs)
      (0.1978003..., 0.3122005...)

`colour.temperature.` `CCT_to_uv_ohno2013`(CCT, Duv=0, cmfs=<colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5c10>)

  Returns the CIE UCS colourspace uv chromaticity coordinates from given correlated colour temperature \(T_{cp}\), \(\Delta_{uv}\) and colour matching functions using Yoshi Ohno (2013) method.

  Parameters: | CCT (numeric) – Correlated colour temperature \(T_{cp}\). Duv (numeric, optional) – \(\Delta_{uv}\). cmfs (XYZ_ColourMatchingFunctions, optional) – Standard observer colour matching functions.
  Returns: | CIE UCS colourspace uv chromaticity coordinates.
  Return type: | tuple

  References

  [3] | Yoshi Ohno, Practical Use and Calculation of CCT and Duv

  Examples

      >>> from colour import STANDARD_OBSERVERS_CMFS
      >>> cmfs = 'CIE 1931 2 Degree Standard Observer'
      >>> cmfs = STANDARD_OBSERVERS_CMFS.get(cmfs)
      >>> CCT = 6507.4342201047066
      >>> Duv = 0.003223690901512735
      >>> CCT_to_uv_ohno2013(CCT, Duv, cmfs)
      (0.1978003..., 0.3122005...)

`colour.temperature.` `CCT_to_uv_robertson1968`(CCT, Duv=0)

  Returns the CIE UCS colourspace uv chromaticity coordinates from given correlated colour temperature \(T_{cp}\) and \(\Delta_{uv}\) using Robertson (1968) method.

  Parameters: | CCT (numeric) – Correlated colour temperature \(T_{cp}\). Duv (numeric) – \(\Delta_{uv}\).
  Returns: | CIE UCS colourspace uv chromaticity coordinates.
  Return type: | tuple

  References

  [6] | Wyszecki & Stiles, Color Science - Concepts and Methods Data and Formulae - Second Edition, Wiley Classics Library Edition, published 2000, ISBN-10: 0-471-39918-3, page 227.

  [7] | Adobe DNG SDK 1.3.0.0: dng_sdk_1_3/dng_sdk/source/dng_temperature.cpp: dng_temperature::xy_coord.

  Examples

      >>> CCT = 6500.0081378199056
      >>> Duv = 0.0083333312442250979
      >>> CCT_to_uv_robertson1968(CCT, Duv)
      (0.1937413..., 0.3152210...)

`colour.temperature.` `uv_to_CCT`(uv, method=u'Ohno 2013', **kwargs)

  Returns the correlated colour temperature \(T_{cp}\) and \(\Delta_{uv}\) from given CIE UCS colourspace uv chromaticity coordinates using given method.

  Parameters: | uv (array_like) – CIE UCS colourspace uv chromaticity coordinates. method (unicode) – (‘Ohno 2013’, ‘Robertson 1968’) Computation method. **kwargs (**) – Keywords arguments.
  Returns: | Correlated colour temperature \(T_{cp}\), \(\Delta_{uv}\).
  Return type: | tuple
  Raises: | `ValueError` – If the computation method is not defined.

  Examples

      >>> from colour import STANDARD_OBSERVERS_CMFS
      >>> cmfs = 'CIE 1931 2 Degree Standard Observer'
      >>> cmfs = STANDARD_OBSERVERS_CMFS.get(cmfs)
      >>> uv_to_CCT((0.1978, 0.3122), cmfs=cmfs)
      (6507.5470349..., 0.0032236...)

`colour.temperature.` `uv_to_CCT_ohno2013`(uv, cmfs=<colour.colorimetry.cmfs.XYZ_ColourMatchingFunctions object at 0x102cf5c10>, start=1000, end=100000, count=10, iterations=6)

  Returns the correlated colour temperature \(T_{cp}\) and \(\Delta_{uv}\) from given CIE UCS colourspace uv chromaticity coordinates, colour matching functions and temperature range using Yoshi Ohno (2013) method.

  The iterations parameter defines the calculations precision: The higher its value, the more planckian tables will be generated through cascade expansion in order to converge to the exact solution.

  Parameters: | uv (array_like) – CIE UCS colourspace uv chromaticity coordinates. cmfs (XYZ_ColourMatchingFunctions, optional) – Standard observer colour matching functions. start (numeric, optional) – Temperature range start in kelvins. end (numeric, optional) – Temperature range end in kelvins. count (int, optional) – Temperatures count in the planckian tables. iterations (int, optional) – Number of planckian tables to generate.
  Returns: | Correlated colour temperature \(T_{cp}\), \(\Delta_{uv}\).
  Return type: | tuple

  References

  [2] | Yoshi Ohno, Practical Use and Calculation of CCT and Duv

  Examples

      >>> from colour import STANDARD_OBSERVERS_CMFS
      >>> cmfs = 'CIE 1931 2 Degree Standard Observer'
      >>> cmfs = STANDARD_OBSERVERS_CMFS.get(cmfs)
      >>> uv_to_CCT_ohno2013((0.1978, 0.3122), cmfs)
      (6507.5470349..., 0.0032236...)

`colour.temperature.` `uv_to_CCT_robertson1968`(uv)

  Returns the correlated colour temperature \(T_{cp}\) and \(\Delta_{uv}\) from given CIE UCS colourspace uv chromaticity coordinates using Robertson (1968) method.

  Parameters: | uv (array_like) – CIE UCS colourspace uv chromaticity coordinates.
  Returns: | Correlated colour temperature \(T_{cp}\), \(\Delta_{uv}\).
  Return type: | tuple

  References

  [4] | Wyszecki & Stiles, Color Science - Concepts and Methods Data and Formulae - Second Edition, Wiley Classics Library Edition, published 2000, ISBN-10: 0-471-39918-3, page 227.

  [5] | Adobe DNG SDK 1.3.0.0: dng_sdk_1_3/dng_sdk/source/dng_temperature.cpp: dng_temperature::Set_xy_coord.

  Examples

      >>> uv = (0.19374137599822966, 0.31522104394059397)
      >>> uv_to_CCT_robertson1968(uv)
      (6500.0162879..., 0.0083333...)

`colour.temperature.` `CCT_to_xy`(CCT, method=u'Kang 2002')

  Returns the CIE XYZ colourspace xy chromaticity coordinates from given correlated colour temperature \(T_{cp}\) using given method.

  Parameters: | CCT (numeric) – Correlated colour temperature \(T_{cp}\). method (unicode (‘Kang 2002’, ‘CIE Illuminant D Series’)) – Computation method.
  Returns: | xy chromaticity coordinates.
  Return type: | tuple

`colour.temperature.` `CCT_to_xy_kang2002`(CCT)

  Returns the CIE XYZ colourspace xy chromaticity coordinates from given correlated colour temperature \(T_{cp}\) using Kang, Moon, Hong, Lee, Cho and Kim (2002) method.

  Parameters: | CCT (numeric) – Correlated colour temperature \(T_{cp}\).
  Returns: | xy chromaticity coordinates.
  Return type: | tuple
  Raises: | `ValueError` – If the correlated colour temperature is not in appropriate domain.

  References

  [10] | Design of Advanced Color - Temperature Control System for HDTV Applications

  Examples

      >>> CCT_to_xy_kang2002(6504.38938305)
      (0.3134259..., 0.3235959...)

`colour.temperature.` `CCT_to_xy_illuminant_D`(CCT)

  Converts from the correlated colour temperature \(T_{cp}\) of a CIE Illuminant D Series to the chromaticity of that CIE Illuminant D Series.

  Parameters: | CCT (numeric) – Correlated colour temperature \(T_{cp}\).
  Returns: | xy chromaticity coordinates.
  Return type: | tuple
  Raises: | `ValueError` – If the correlated colour temperature is not in appropriate domain.

  References

  [11] | Wyszecki & Stiles, Color Science - Concepts and Methods Data and Formulae - Second Edition, Wiley Classics Library Edition, published 2000, ISBN-10: 0-471-39918-3, page 145.

  Examples

      >>> CCT_to_xy_illuminant_D(6504.38938305)
      (0.3127077..., 0.3291128...)

`colour.temperature.` `xy_to_CCT`(xy, method=u'McCamy 1992', **kwargs)

  Returns the correlated colour temperature \(T_{cp}\) from given CIE XYZ colourspace xy chromaticity coordinates using given method.

  Parameters: | xy (array_like) – xy chromaticity coordinates. method (unicode (‘McCamy 1992’, ‘Hernandez 1999’)) – Computation method. **kwargs (**) – Keywords arguments.
  Returns: | Correlated colour temperature \(T_{cp}\).
  Return type: | numeric

`colour.temperature.` `xy_to_CCT_mccamy1992`(xy)

  Returns the correlated colour temperature \(T_{cp}\) from given CIE XYZ colourspace xy chromaticity coordinates using McCamy (1992) method.

  Parameters: | xy (array_like) – xy chromaticity coordinates.
  Returns: | Correlated colour temperature \(T_{cp}\).
  Return type: | numeric

  References

  [8] | http://en.wikipedia.org/wiki/Color_temperature#Approximation (Last accessed 28 June 2014)

  Examples

      >>> xy_to_CCT_mccamy1992((0.31271, 0.32902))
      6504.3893830...

`colour.temperature.` `xy_to_CCT_hernandez1999`(xy)

  Returns the correlated colour temperature \(T_{cp}\) from given CIE XYZ colourspace xy chromaticity coordinates using Hernandez-Andres, Lee & Romero (1999) method.

  Parameters: | xy (array_like) – xy chromaticity coordinates.
  Returns: | Correlated colour temperature \(T_{cp}\).
  Return type: | numeric

  References

  [9] | Calculating correlated color temperatures across the entire gamut of daylight and skylight chromaticities

  Examples

      >>> xy_to_CCT_hernandez1999((0.31271, 0.32902))
      6500.0421533...